@@ -9,6 +9,7 @@ from .ntypes import (
 )
 from .manager import Manager
 import pandas as pd
+import warnings
 import os
 
 
@@ -16,21 +17,34 @@ class Assets:
     naas = None
     manager = None
     role = t_asset
+    deprecated_name = False
 
-    def __init__(self):
+    def __init__(self, deprecated_name=False):
         self.manager = Manager(t_asset)
         self.path = self.manager.path
+        self.deprecated_name = deprecated_name
+
+    def deprecatedPrint(self):
+        # TODO remove this in june 2021
+        if self.deprecated_name:
+            warnings.warn(
+                "[Warning], naas.assets is deprecated,\n use naas.asset instead, it will be remove in 1 june 2021"
+            )
 
     def list(self, path=None):
+        self.deprecatedPrint()
         return self.manager.list_prod("list_history", path)
 
     def get(self, path=None, histo=None):
+        self.deprecatedPrint()
         return self.manager.get_file(path, histo=histo)
 
     def clear(self, path=None, histo=None):
+        self.deprecatedPrint()
         return self.manager.clear_file(path, None, histo)
 
     def currents(self, raw=False):
+        self.deprecatedPrint()
         copy_clipboard()
         json_data = self.manager.get_naas()
         json_filtered = []
@@ -52,6 +66,7 @@ class Assets:
         return json_filtered
 
     def find(self, path=None):
+        self.deprecatedPrint()
         current_file = self.manager.get_path(path)
         if current_file is None:
             print("Missing file path")
@@ -63,6 +78,7 @@ class Assets:
             return None
 
     def add(self, path=None, params={}, debug=False):
+        self.deprecatedPrint()
         current_file = self.manager.get_path(path)
         if current_file is None:
             print("Missing file path")
@@ -95,6 +111,7 @@ class Assets:
         return url
 
     def delete(self, path=None, all=True, debug=False):
+        self.deprecatedPrint()
         if self.manager.is_production():
             print("No delete done, you are in production\n")
             return
